@@ -2,7 +2,7 @@ package CGI::Compile;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use Cwd;
 use File::Basename;
@@ -44,7 +44,7 @@ sub compile {
         "my \$_dir = File::pushd::pushd '$dir';",
         'local *DATA;',
         q{open DATA, '<', \$data;},
-        'local %SIG;',
+        'local *SIG = +{ %SIG };',
         'my $rv = eval {',
         "\n#line 1 $path\n",
         $code,
